lxm3.xm\_cluster.Fileset
========================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: Fileset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Fileset.__init__
      ~Fileset.add_path
      ~Fileset.get_path
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Fileset.files
   
   